/*
 *  main.c: Main program
 *
 *  Copyright (C) 2010- John Coppens (john@jcoppens.com)        
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 3 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *  
 *  You should have received a copy of the GNU Library General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

/*
 * Initial main.c file generated by Glade. Edit as required.
 * Glade will not overwrite this file.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <getopt.h>
#include <gtk/gtk.h>
#include <string.h>
#include <libintl.h>

#include "interface.h"
#include "support.h"
#include "pref.h"
#include "main.h"

GtkWidget *MainWindow;
GtkWidget *PrefWindow;
GtkWidget *ConversionsWindow;
GtkWidget *VariablesWindow;
GtkWidget *InspectorWindow;
GtkWidget *ExtrasPopup;
GtkWidget *ResultPopup;
GtkWidget *NrDigitsPopup;
GtkWidget *AddVariableWindow;

unsigned debug;

void
show_help(void)
{
  printf(_("gWcalc frontend for the wcalc calculator\n"
           "\n"
           "Usage:  gwcalc [-d <options>]\n"
           "\n"
           "  -d    enables debugging\n"
           "     r    show wcalc reply\n"
	   "     c    show the wcalc command line\n"
	   "     e    show wcalc error messages\n"
           "  -?\n"
           "  -h    show this help\n"
	   "\n"));

  gtk_exit(0);
}

void
check_params(int argc, char *argv[])
{
  int i, c;

  while ((i = getopt (argc, argv, "d:h?")) != EOF) {
    switch (i) {
      case 'd': 
        for (c = 0; c < strlen(optarg); c++) {
          switch (optarg[c]) {
            case 'r': debug |= DBG_REPLY; break;	// wcalc's result replies
	    case 'c': debug |= DBG_COMMAND; break;	// wcalc command line
	    case 'e': debug |= DBG_ERRORS; break;	// wcalc's error messages
	  }
        }
        break;  
      case '?': 
      case 'h':
        show_help();
        break;
    }
  }
}


int
main (int argc, char *argv[])
{

#ifdef ENABLE_NLS
  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
  textdomain (GETTEXT_PACKAGE);
#endif

  gtk_set_locale ();

  check_params(argc, argv);
  gtk_init (&argc, &argv);

  add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE "/pixmaps");

  /*
   * The following code was added by Glade to create one of each component
   * (except popup menus), just so that you see something after building
   * the project. Delete any components that you don't want shown initially.
   */

  load_preferences();

  MainWindow = create_MainWindow();
  gtk_widget_show(MainWindow);

  gtk_main ();
  return 0;
}

